' Lawson Labs, Inc.
' 3239 Phoenixville Pike
' Malvern, PA   19355
' 800 321-5355 or 610 725-8800
' www.lawsonlabs.com

' Sigma-Delta Subsystem Driver         Rev 1.0
' March 2, 1992


'      SPECIFICATIONS
'
' AC CONTROL       VOLTAGE: 30 to 250 VAC RMS at 200 MA
'  OUTPUTS          MINIMUM LOAD CURRENT: 1 MA RMS
'

' HIGH-LEVEL       MINIMUM "ON" VOLTAGE: 20 Volts DC or AC peak
' DIGITAL INPUTS    MAXIMUM "OFF" VOLTAGE: 2 Volts DC or AC peak
'                   MAXIMUM VOLTAGE: 250 Volts DC or AC peak
'
' ISOLATED         SUPPLY VOLTAGE: 18.5 to 50 VDC at 100 milliamps
' ANALOG INPUT      INPUT RANGE: 0 to 25 milliamps nominal
'                   LINEARITY: 0.1% of full scale
'    
' ISOLATED         SUPPLY VOLTAGE: 18.5 to 50 VDC at 200 milliamps
' ANALOG OUTPUT     NOMINAL OUTPUT RANGE: 0 to 10 VDC or 0 to 25 milliamps
'                   LINEAR RANGE: .2 to 9.8 VDC or .5 to 24.5 milliamps
'                   LINEARITY: 0.1% of full scale
'                   TIME CONSTANT: .5 seconds maximum
'                   RESOLUTION: 1 part in 8192 (13-bits) monotonic
'
' WATCHDOG         1 second refresh rate
'  TIMER            1.5 second timeout nominal
'
' SCALE INPUT      20-BIT NOMINAL RESOLUTION
'                   CLOCK JUMPER POSITION:    1           2           3
'                   UPDATE RATE:            218 Hz      874 Hz     3496 Hz
'                   CUTOFF FREQUENCY:       0.5 Hz      2.2 Hz      8.7 Hz
'                   CALIBRATION TIME:        1 sec       4 sec      15 sec
'                  EXCITATION VOLTAGE: 7.5 Volts nominal
'                   GAIN JUMPER POSITION:     1           2           3
'                   AMPLIFIER GAIN:          84x        150x        250x
'                   INPUT RANGE:            0-30 mV     0-17 mV     0-10 mV
'                   SENSITIVITY:           4.0 mV/V    2.2 mV/V    1.3 mV/V
'                  TEMPERATURE STABILIZED AT 45 deg C nominal
'                   OTHER TEMPERATURES AVAILABLE WITH FACTORY MODIFICATION
'
  
  GOSUB S1                      ' get DIP switch setting
                                ' ADC% is now set to the base address
                                ' as shipped, ADC%= 512 decimal (200H)
'       HARDWARE PORT ADDRESSES (RELATIVE TO ADC%)

' The first 8 ports are a pair of 8253 counters, A & B. They are accessed
' by adding their port number to ADC%

  TIMEBASE% = 0                 ' Counter A0 MODE 2, 3.58 MHz clock input
                                ' Set for 4.577 ms period out
                                ' count is set to 16384
  ANALOGOUT1% = 1               ' Counter A1 analog output
                                ' MODE 1, 3.58 MHz clock
                                ' 1 to 16384 counts = 0 to 10 VDC out
  AUX% = 2                      ' Auxiliary counter, externally clocked
                                ' MODE 0, always enabled
' Displacement of 3 is mode register for counter A     
 
  ANALOGPERIOD% = 4             ' Counter B0 Time base counter,
                                ' MODE 1, clocked by 4.577 ms signal
                                ' set for 192.24 ms, 42 counts
  ANALOGIN% = 5                 ' Counter B1 Analog input counter,
                                ' MODE 0, 0-25KHZ clock,
                                ' Enabled by B0, 4806 counts max at 25KHZ
                                ' the count is proportional to the
                                ' input current
  ANALOGOUT2% = 6               ' Counter B2, just like ANALOGOUT1%
' Displacement of 7 is mode register for counter B      

  LOWDATA% = ADC% + 8           ' READ Least significant byte of conversion
  MIDDATA% = ADC% + 9           ' READ Middle byte of conversion
  HIGHDATA% = ADC% + 10         ' READ Most significant nibble of conversion
  
  TTLINA% = ADC% + 11           ' READ TTL level input byte A
  TTLINB% = ADC% + 12           ' READ TTL level input byte B
  DIGITALIN% = ADC% + 13        ' READ AC or DC High level input nibble,
                                ' bits 0 - 3
  WATCHDOG% = ADC% + 14         ' READ Retriggers watchdog. Timeout is
                                ' 1 to 2 seconds. Data read means nothing.
                                ' Timeout clears DIGOUTA%, DIGOUTB% and
                                ' CONTROL% outputs
  STARTCONV% = ADC% + 15        ' READ begins optional A/D conversion
  DIGOUTA% = ADC% + 8           ' WRITE TTL level output byte A
  DIGOUTB% = ADC% + 9           ' WRITE TTL level output byte B
  CONTROL% = ADC% + 10          ' WRITE control word : 1 = ACTIVE
                                '      BIT
                                '       0       AC control 0
                                '       1       AC control 1
                                '       2       AC control 2
                                '       3       AC control 3
                                '       4       CALIBRATE SIGMA DELTA
                                '       5       UNFREEZE SIGMA DELTA
 CAL% = &H10                    ' calibration mask OR
 FREEZEON% = &H1F               ' freeze on mask AND
 FREEZEOFF% = &H20              ' freeze off mask OR

INITCONTROL:
             CWORD% = FREEZEOFF%        ' set current control word.
                                        ' CWORD% tracks the current
                                        ' control word
             OUT CONTROL%, CWORD%       ' default control word, UNFREEZE
                                        ' HIGH, all relays off.

TIMER ON                                ' read watchdog every second
GOSUB WATCH                             ' start watchdog
ON TIMER(1) GOSUB WATCH                 ' restart every second

GOSUB CALIBRATE                         ' calibrate sigma delta chip

INITCNTRS:                              ' initialize counters                     
        CNTPORT% = TIMEBASE%                    ' set counter A0
        COUNT = 16384: GOSUB WRITECNTR          ' load count for 4.577 ms
        CNTPORT% = ANALOGOUT1%                  ' set counter A1
        COUNT = 1: GOSUB WRITECNTR              ' load count for 0 VDC
        CNTPORT% = AUX%                         ' set counter A2
        COUNT = 0: GOSUB WRITECNTR              ' load count of 0
     ' this count will not appear when reading the counter until
     '  two clock pulses have occured
        CNTPORT% = ANALOGPERIOD%                ' set counter B0
        ADCNT% = 42                             ' count for A/D gate time
        COUNT = ADCNT%: GOSUB WRITECNTR         ' load count for 192.24 ms
        PERIOD = COUNT * 4.577                  ' conversion period
        FULLSCALECOUNT = PERIOD / .04           ' maximum # of counts
                                                ' during conversion period
                                                ' at 25 KHZ
'    increasing ADCNT% increases resolution and decreases speed
'    decreasing ADCNT% decreases resolution and increases speed
'    With value of 42, conversion takes 192 ms and resolves 1 part in 4806
       
        CNTPORT% = ANALOGIN%                    ' set counter B1
        COUNT = 0: GOSUB WRITECNTR              ' load count of 0
    ' two clock pulses are needed to initialize the counter.
        GOSUB READCNTR                          ' read counter B1
        LASTCNT = COUNT                         ' initialize LASTCNT
RETRY:  X% = INP(STARTCONV%)                    ' trigger counter B0
        GOSUB WAITING                           ' let it timeout
        GOSUB READCNTR                          ' read counter B1 
        IF COUNT = LASTCNT THEN GOTO RETRY      ' repeat until loaded
        LASTCNT = COUNT                         ' initialize LASTCNT
        CNTPORT% = ANALOGOUT2%                  ' set counter B2
        COUNT = 1: GOSUB WRITECNTR              ' load count for 0 VDC

MENU:
      KEY OFF: CLS
      LOCATE 2, 10: PRINT "1)  Read digital inputs"
      LOCATE 4, 10: PRINT "2)  Set digital outputs"
      LOCATE 6, 10: PRINT "3)  Read isolated analog input "
      LOCATE 8, 10: PRINT "4)  Set isolated analog outputs"
      LOCATE 10, 10: PRINT "5)  Read sigma delta"
      LOCATE 12, 10: PRINT "6)  Read AUX counter";
      LOCATE 14, 10: PRINT "Any other key to exit"
MENUSEL: A$ = INKEY$: IF A$ = "" THEN GOTO MENUSEL
      SEL = VAL(A$): CLS
 SELECT CASE SEL
  CASE 1: GOSUB DIGITALIN: CASE 2: GOSUB DIGITALOUT: CASE 3: GOSUB ANALOGIN
  CASE 4: GOSUB ANALOGOUT: CASE 5: GOSUB DELTASIG: CASE 6: GOSUB AUXCNTR
  CASE ELSE: END
 END SELECT
 GOTO MENU

WRITECNTR:    ' expects CNTPORT% set to port address relative to ADC%
              ' and COUNT set to count to load
 CH = INT(COUNT / 256)                  ' get hi and lo bytes of count
 CL = FIX(COUNT - CH * 256)
 C% = CNTPORT% MOD 4                    ' set C% to counter number
 IF C% = CNTPORT% THEN CMODE% = ADC% + 3 ELSE CMODE% = ADC% + 7
 CM% = 1                                ' set default mode
 IF CNTPORT% = 0 THEN CM% = 2           ' find correct mode
 IF (CNTPORT% = 5) OR (CNTPORT% = 2) THEN CM% = 0
 OUT CMODE%, 48 + C% * 64 + CM% * 2     ' set counter mode
 OUT (CNTPORT% + ADC%), CL              ' output count
 OUT (CNTPORT% + ADC%), CH
RETURN

READCNTR:       'expects CNTPORT% set to port address relative to ADC%
 C% = CNTPORT% MOD 4                    ' set C% to counter number
 IF C% = CNTPORT% THEN CMODE% = ADC% + 3 ELSE CMODE% = ADC% + 7
 OUT CMODE%, C% * 64                    ' latch counter for read
 L% = INP(CNTPORT% + ADC%)              ' read it
 H = INP(CNTPORT% + ADC%)
 COUNT = L% + H * 256                   ' return with COUNT
RETURN

AUXCNTR:                                ' display AUX counter reading
  CNTPORT% = AUX%                       ' select aux counter
  GOSUB PRESSKEY                        ' display prompt
READLOOP: GOSUB READCNTR
  LOCATE 10, 10: PRINT USING "######"; COUNT
  IF INKEY$ <> " " THEN GOTO READLOOP
RETURN

S1:           ' get switch settings
              ' as shipped, all switches ON except #6 for ADC%= 512 decimal
   CLS : PRINT "Enter ADC or DIP switch setting in binary."
   PRINT "(For binary, use 1 for ON and 0 for OFF. Start with switch #6)";
   INPUT A$
   IF LEN(A$) <> 6 THEN GOTO DECIMAL
   ADC% = 0: FOR N% = 1 TO 6
   ADC% = ADC% + (2 ^ (6 - N%)) * ABS(VAL(MID$(A$, N%, 1)) - 1)
   NEXT N%: ADC% = ADC% * 16: A$ = STR$(ADC%)
DECIMAL:
   IF LEN(A$) > 4 THEN GOTO S1
   ADC% = VAL(A$)
   PRINT "ADC% in decimal="; ADC%, "ADC% in Hex="; HEX$(ADC%)
   PRINT "Enter space to continue or Esc to re-enter. ": A$ = INPUT$(1)
   IF A$ = CHR$(27) THEN CLS : GOTO S1
RETURN          'S1

' To read data out of the sigma delta converter, bring the UNFREEZE bit LOW,
' read LOWDATA%, MIDDATA%, and HIGHDATA% then set the UNFREEZE bit HIGH.
' The recommended operating range is -2.25 at zero and +2.25 at full scale.
' The WATCHDOG timer must be active or the converter cannot be read.

DELTASIG:  CLS
 GOSUB PRESSKEY
 LOCATE 24, 38: PRINT ", any other key to reset Max and Min ";
 LOCATE 1, 1: PRINT "  Count     Volts      Min         Max        Spread";
 LOCATE 3, 1
 MIN = 2.5: MAX = -2.5
 AVG% = 1                          ' set AVG% to # of points to average
 CWORD% = CWORD% AND FREEZEON%     ' set freeze on as default control word
 OUT CONTROL%, (CWORD% OR FREEZEOFF%) ' enable update of output latch
AVGLOOP:
 H = 0: M = 0: L = 0                ' initialize data readout
 FOR N = 1 TO AVG%                  ' average loop counter
   OUT CONTROL%, CWORD%             ' latch output data
   H = H + (INP(HIGHDATA%) AND &HF) ' get the 4 most significant bits
   M = M + INP(MIDDATA%)            ' get middle byte
   L = L + INP(LOWDATA%)            ' get low byte
   OUT CONTROL%, (CWORD% OR FREEZEOFF%)  ' enable update of output latch
 NEXT                               ' get next data for averaging
 GOSUB CNTOVOLTS                    ' convert data to volts
 IF CSRLIN = 23 THEN LOCATE 3, 1    ' wrap around to top of screen
 GOTO AVGLOOP                       ' do another average loop

' To calibrate the A/D converter, bring the CALIBRATE BIT HIGH, then LOW.
' The calibration will take 1-15 seconds. The data from the converter is
' invalid until the calibration is complete.
CALIBRATE:                       ' perform calibration
 OUT CONTROL%, (CWORD% OR CAL%)  ' set calibration bit
 OUT CONTROL%, (CWORD% AND &H2F) ' clear calibration bit
RETURN                           ' end of calibration

CNTOVOLTS:     ' start of count to volts conversion routine
 COUNT! = L / AVG% + (M / AVG%) * 256 + (H / AVG%) * 65536!' combine counts
 PRINT USING "########"; COUNT!;             ' print count
 VOLTS = COUNT! * 4.76837E-06 - 2.5          ' convert to volts
 PRINT USING "#####.#####"; VOLTS;           ' print volts
 IF VOLTS < MIN THEN MIN = VOLTS             ' set minimum reading
 IF VOLTS > MAX THEN MAX = VOLTS             ' set maximum reading
 PRINT USING "#####.#####"; MIN;             ' print minimum reading
 PRINT USING "#####.#####"; MAX;             ' print maximum reading
 PRINT USING "#####.#####"; MAX - MIN        ' print the spread
 A$ = INKEY$                                 ' check for keypress
 IF A$ = " " THEN RETURN MENU                ' exit to main menu
 IF A$ <> "" THEN MIN = 2.5: MAX = -2.5      ' reset min & max
RETURN                                       ' end of conversion routine

DIGITALIN: CLS ' read & display DIGITALIN% & TTLA% & TTLB%
DIG2:
   X% = INP(DIGITALIN%): Y% = INP(TTLINA%): Z% = INP(TTLINB%) 'read inputs
   LOCATE 1, 1: PRINT "         Digital Input          ";
   PRINT "    TTLA Input           TTLB Input"          'print display header
   PRINT : PRINT "Hexadecimal=      "; HEX$(X% MOD 16);
   PRINT SPACE$(23); HEX$(INT(Y% / 16)); HEX$(Y% MOD 16);
   PRINT SPACE$(19); HEX$(INT(Z% / 16)); HEX$(Z% MOD 16);
   PRINT : PRINT : PRINT SPACE$(16); : NQ% = 3: GOSUB DECBIN: NQ% = 7
   PRINT SPACE$(18); : X% = Y%: GOSUB DECBIN
   PRINT SPACE$(13); : X% = Z%: GOSUB DECBIN
   GOSUB PRESSKEY
   IF INKEY$ <> " " THEN GOTO DIG2
 RETURN       'DIGITALIN

DECBIN:      ' Print X% in binary 0<X%<256. NQ%= binary places -1
   FOR NN% = NQ% TO 0 STEP -1
   IF X% AND 2 ^ NN% THEN PRINT "1";  ELSE PRINT "0";
   NEXT NN%: RETURN

PRESSKEY:                        '  PRINT  Press space ...
   LOCATE 24, 5: PRINT "Press space bar to return to menu";
RETURN

DIGITALOUT:
   CLS : PRINT "Enter port to output 1 = DIGOUTA, 2 = DIGOUTB, 3 = CONTROL "
GETKEY: A% = VAL(INKEY$): IF A% < 1 OR A% > 3 THEN GOTO GETKEY
PRINT "port "; A%
IF A% = 3 THEN DMAX% = 15 ELSE DMAX% = 255
PRINT "Enter digital output 0 -"; DMAX%
  GOSUB GETINPUTSTR: DIGCODE% = VAL(INPUTSTR$)
  IF DIGCODE% > DMAX% OR DIGCODE% < 0 THEN GOTO DIGITALOUT
  IF A% = 1 THEN OUT DIGOUTA%, DIGCODE%
  IF A% = 2 THEN OUT DIGOUTB%, DIGCODE%
  IF A% = 3 THEN OUT CONTROL%, DIGCODE%
  CWORD% = DIGCODE%  'update current control word
 PRINT : PRINT
 IF A% = 3 THEN DMAX% = 3 ELSE DMAX% = 7
 FOR N% = 0 TO DMAX%
 PRINT N%; " is "; : IF DIGCODE% AND 2 ^ N% THEN PRINT " ON" ELSE PRINT "OFF"
 NEXT N%
GOSUB PRESSKEY: LOCATE 24, 38: PRINT ", any other key to continue";
WAITKEY: A$ = INKEY$: IF A$ = "" THEN GOTO WAITKEY
   IF A$ <> " " THEN GOTO DIGITALOUT
RETURN   'DIGITALOUT

GETINPUTSTR:       ' gets characters until Enter is pressed, used instead
  INPUTSTR$ = ""   ' of INPUT$ so that ON TIMER functions regularly
STRINPUT: II$ = INKEY$: IF II$ = "" THEN GOTO STRINPUT
  IF II$ = CHR$(13) THEN RETURN
  INPUTSTR$ = INPUTSTR$ + II$: PRINT II$; : GOTO STRINPUT


ANALOGOUT:
   CLS : PRINT "Enter analog output, 1 or 2 ";
KEYWAIT:  CNT$ = INKEY$: IF CNT$ = "" THEN GOTO KEYWAIT
   CNT$ = UCASE$(CNT$)
   IF CNT$ <> "1" AND CNT$ <> "2" THEN GOTO ANALOGOUT
   IF CNT$ = "1" THEN CNTPORT% = ANALOGOUT1% ELSE CNTPORT% = ANALOGOUT2%
ENTERV:
   CLS : VOLTS$ = "": PRINT "Enter output voltage 0 - 10V ";
   GOSUB GETINPUTSTR
   VOLTS = VAL(INPUTSTR$)
   IF VOLTS < 0 OR VOLTS > 10 THEN GOTO ENTERV
   COUNT = VOLTS * 1638.3 + 1         'calculate counts
   GOSUB WRITECNTR
   GOSUB PRESSKEY: LOCATE 24, 38: PRINT ", any other key to continue";
WAITINPUT: A$ = INKEY$: IF A$ = "" THEN GOTO WAITINPUT
   IF A$ <> " " THEN GOTO ANALOGOUT
RETURN          'ANALOGOUT

ANALOGIN:
   CLS : PRINT "    COUNT       MILLIAMPS      ";
   PRINT "MAXIMUM COUNT         MINIMUM COUNT ";
   GOSUB PRESSKEY
   LOCATE 24, 38: PRINT ", any other key to reset max and min";
   CNTPORT% = ANALOGIN%
   ROW% = 3                              ' row for display
   MAXCOUNT = 0: MINCOUNT = 32000 'init vars
AN1:
   X% = INP(STARTCONV%)                         ' trigger counter B0
                
   GOSUB WAITING    ' now wait PERIOD plus .1 second before reading count
   GOSUB READCNTR   ' read cntr B1
   CNT = LASTCNT - COUNT                ' find difference in count
   LASTCNT = COUNT
   IF CNT < 0 THEN CNT = CNT + 65536      ' adjust for wraparound
   MAMP = CNT / PERIOD                    ' convert to milliamps
   LOCATE ROW%, 2: PRINT USING "#######"; CNT;
   LOCATE ROW%, 16: PRINT USING "####.##"; MAMP;
   IF CNT > MAXCOUNT THEN MAXCOUNT = CNT
   IF CNT < MINCOUNT THEN MINCOUNT = CNT
   LOCATE 3, 35: PRINT USING "#######"; MAXCOUNT; TAB(56); MINCOUNT;
   ROW% = ROW% + 1: IF ROW% = 22 THEN ROW% = 3   'do not scroll screen
   A$ = INKEY$: IF A$ = "" THEN GOTO AN1
   IF A$ <> " " THEN MAXCOUNT = 0: MINCOUNT = 32000: GOTO AN1
RETURN          'ANALOGIN

WAITING:            
   TT = TIMER: IF TT > 86385 THEN GOTO WAITING     ' avoid wraparound
   TT = TT + .1 + (PERIOD / 1000)
NOTDONE: IF TT > TIMER THEN GOTO NOTDONE

WATCH: TT% = INP(WATCHDOG%): RETURN   'restart watchdog


'
'                          CONNECTOR PINOUTS:
'
'
'
'    Board edge fingers (18-position, polarization key between 3 and 4):
'
'       1    High level output #3(a)       A    High level output #3(b)
'       2    High level output #2(a)       B    High level output #2(b)
'       3    High level output #1(a)       C    High level output #1(b)
'       4    High level output #0(a)       D    High level output #0(b)
'       5    External counter in-          E    External counter in+
'       6    High level input #3-          F    High level input #3+
'       7    High level input #2-          G    High level input #2+
'       8    High level input #1-          H    High level input #1+
'       9    High level input #0-          I    High level input #0+
'      10    A/D common                    J    A/D 0-25 ma in
'      11    A/D external +12 volts        K    A/D supply, 18.5-50 vdc
'      12    D/A #1 common                 L    D/A #1 external +12 volts
'      13    D/A #1 supply, 18.5-50 vdc    M    D/A #1 0-25 ma out
'      14    D/A #1 0-10 vdc out           N    D/A #2 0-25 ma out
'      15    D/A #2 supply, 18.5-50 vdc    O    D/A #2 0-10 vdc out
'      16    D/A #2 common                 P    D/A #2 external +12 volts
'      17    Ground                        Q    +5 volts
'      18    -12 volts                     R    +12 volts
'
'
'    36-position header:
'
'       1    High level output #3(a)      19    A/D common
'       2    High level output #3(b)      20    A/D 0-25 ma in
'       3    High level output #2(a)      21    A/D external +12 volts
'       4    High level output #2(b)      22    A/D supply, 18.5-50 vdc
'       5    High level output #1(a)      23    D/A #1 common
'       6    High level output #1(b)      24    D/A #1 external +12 volts
'       7    High level output #0(a)      25    D/A #1 supply, 18.5-50 vdc
'       8    High level output #0(b)      26    D/A #1 0-25 ma out
'       9    External counter in-         27    D/A #1 0-10 vdc out
'      10    External counter in+         28    D/A #2 0-25 ma out
'      11    High level input #3-         29    D/A #2 supply, 18.5-50 vdc
'      12    High level input #3+         30    D/A #2 0-10 vdc out
'      13    High level input #2-         31    D/A #2 common
'      14    High level input #2+         32    D/A #2 external +12 volts
'      15    High level input #1-         33    Ground
'      16    High level input #1+         34    +5 volts
'      17    High level input #0-         35    -12 volts
'      18    High level input #0+         36    +12 volts
'
'
'    Board edge fingers (6-position, polarization key between 2 and 3):
'
'       1    -5 volts                      A    In-
'       2    +12 volts                     B    In+
'       3    Module out                    C    Sense-
'       4    Analog ground                 D    Sense+
'       5    Reference                     E    Force+
'       6    Heater ground                 F    Force-
'
'
'    8-position header:                 6-position header:
'
'       1    Force-                        1    In-
'       2    Force-                        2    In+
'       3    -5 volts                      3    Sense-
'       4    +12 volts                     4    Sense+
'       5    Module out                    5    Force+
'       6    Analog ground                 6    Force-
'       7    Reference
'       8    Heater ground
'
'
'    4-pin power connector:
'
'                       ________________________
'                     /                        /|
'                   /                        /  |
'                 /_______________________ /    /
'                |    //     /     /     /|   /
'                |  /O     O     O     O  | /
'                |/_______________________|
'     ----------------------------------------------------
'                   +5    GND   +12   -12
'
'
'       14-pin dual row digital I/O header
'
'                       Pin Number
'             +5VDC      1      2     Ground
'         Output A1      3      4     Reserved
'         Output A2      5      6     Output A0
'         Output B1      7      8     Output B0
'         Output B3      9      0     Output B2
'         Output B5     11      12    Output B4
'         Output B7     13      14    Output B6
'                   
'        28-pin dual row digital I/O header
'
'                       Pin Number
'           Input A7     1      2     Output A3
'           Input B0     3      4     Output A4
'           Input B1     5      6     Output A5
'           Input B2     7      8     Output A6
'           Input B3     9      10    Output A7
'             Ground    11      12    Input A0
'           Input B4    13      14    Input A1
'           Input B5    15      16    Input A2
'           Input B6    17      18    Input A3
'           Input B7    19      20    Input A4
'           Input A5    21      22    Input A5
'           Input A6    23      24    Input A6
'           Reserved    25      26    Input A7
'             Ground    27      28    Input B0

